@@ -122,10 +122,13 @@ def upload(  # pylint:disable=too-many-locals,too-many-arguments
     # pylint:disable=protected-access
     upload_string(task_id, simulation._json_string, SIM_FILE_JSON)
     if len(simulation.custom_datasets) > 0:
-        # Also upload hdf5 containing all data
-        with tempfile.NamedTemporaryFile() as data_file:
-            simulation.to_hdf5(data_file.name)
-            upload_file(task_id, data_file.name, SIM_FILE_HDF5)
+        # Also upload hdf5 containing all data.
+        # The temp file will be re-opened in `to_hdf5` which can cause an error on some systems
+        # so we explicitly close it first.
+        data_file = tempfile.NamedTemporaryFile()  # pylint:disable=consider-using-with
+        data_file.close()
+        simulation.to_hdf5(data_file.name)
+        upload_file(task_id, data_file.name, SIM_FILE_HDF5)
 
     # log the url for the task in the web UI
     log.debug(f"{DEFAULT_CONFIG.website_endpoint}/folders/{folder.projectId}/tasks/{task_id}")
@@ -210,6 +213,7 @@ def get_run_info(task_id: TaskId):
         return None, None
 
 
+# pylint: disable=too-many-statements
 def monitor(task_id: TaskId) -> None:
     """Print the real time task progress until completion.
 
@@ -245,7 +249,7 @@ def monitor(task_id: TaskId) -> None:
         # log the maximum flex unit cost
         est_flex_unit = task_info.estFlexUnit
         if show_cost is True and est_flex_unit is not None and est_flex_unit > 0:
-            log.info(f"Maximum flex unit cost: {est_flex_unit:1.2f}")
+            log.info(f"Maximum FlexUnit cost: {est_flex_unit:1.3f}")
             # Set show_cost to False so that it is only shown once during the run
             show_cost = False
 
@@ -302,6 +306,9 @@ def monitor(task_id: TaskId) -> None:
                 log.info(f"status = {status}")
             time.sleep(REFRESH_TIME)
 
+    # show final billed cost
+    log.info(f"Billed FlexUnit cost: {get_info(task_id).realFlexUnit:1.3f}")
+
 
 def download(task_id: TaskId, path: str = "simulation_data.hdf5") -> None:
     """Download results of task and log to file.
